@@ -1,5 +1,5 @@
 /*  QuickSynergy -- a GUI for synergy
- *  Copyright (C) 2006 César L. B. Silveira, Otávio C. Cordeiro
+ *  Copyright (C) 2006, 2007 Cesar L. B. Silveira, Otavio C. Cordeiro
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,11 +24,9 @@
 #include <signal.h>
 #include <unistd.h>
 #include <gtk/gtk.h>
+#include "synergy_config.h"
 #include "config.h"
-#include "logo_data.h"
-#include "proc.h"
-
-#define VERSION "0.5"
+#include "intl.h"
 
 extern GtkWidget *main_window;
 extern GtkWidget *notebook;
@@ -37,7 +35,7 @@ extern GtkWidget *table;
 extern GtkWidget *vbox0;
 extern int synergy_running;
 extern int keep_running;
-extern pid_t pid;
+extern const guint8 qslogo[];
 
 gboolean entry_focus_in_event(
         GtkWidget *widget, GdkEventFocus *event, gpointer data) {
@@ -86,21 +84,24 @@ void about_button_clicked(GtkWidget *widget, gpointer data) {
     gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(about), "quicksynergy");
     gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about), VERSION);
     gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about), 
-            gdk_pixbuf_new_from_xpm_data((const char**)logo_data));
+            gdk_pixbuf_new_from_inline(-1, qslogo, FALSE, NULL));
     gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about),
-            "A GUI for synergy");
+            _("A GUI for synergy"));
     gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(about), 
             "http://quicksynergy.sourceforge.net");
     gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(about), 
             (const gchar **) authors);
     gtk_about_dialog_set_documenters(GTK_ABOUT_DIALOG(about), 
             (const gchar **) documenters);
+    gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG(about),
+            _("translator-credits"));
 
-    gtk_widget_show_all(about);
+    gtk_dialog_run(GTK_DIALOG(about));
+    gtk_widget_destroy(about);
 }
 
 void start_button_clicked(GtkWidget *widget, gpointer data) {
-	struct entry_data *entries = (struct entry_data *) data;
+	GtkWidget **entries = (GtkWidget **) data;
 	const char *env_home = getenv("HOME");
 	char *filename, *hostname, *command;
 	GtkWidget *stock;
@@ -108,8 +109,8 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
 	
 	if(!synergy_running) {	
 		if(gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)) == 0) {	
-			save_config(entries);
-			save_synergy_config(entries);
+			save_config(entries[0], entries[1], entries[2], entries[3]);
+			save_synergy_config(entries[0], entries[1], entries[2], entries[3]);
 		
 			filename = (char *) malloc(
 				(strlen(env_home) + strlen("/.quicksynergy/synergy.conf")) * 
@@ -117,7 +118,7 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
 		
 			sprintf(filename, "%s%s", env_home, "/.quicksynergy/synergy.conf");
 			
-			if((pid = fork()) == 0) {
+			if((fork()) == 0) {
 			    if(keep_running) {
     				execlp("synergys", "synergys", "--config",  filename, NULL);
     			}
@@ -139,7 +140,7 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
 			hostname = 
                 (char *) gtk_entry_get_text(GTK_ENTRY(hostname_entry));
 			
-			if((pid = fork()) == 0) {
+			if((fork()) == 0) {
 			    if(keep_running) {
     				execlp("synergyc", "synergyc", hostname, NULL);
     			}
@@ -153,23 +154,20 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
     	    }
 		}
 		
-    	gtk_button_set_label(GTK_BUTTON(widget), "Stop");		
+    	gtk_button_set_label(GTK_BUTTON(widget), _("Stop"));		
 		gtk_widget_set_sensitive(notebook, FALSE);
     
     	synergy_running = 1;
 	}
 	else {
-		gtk_button_set_label(GTK_BUTTON(widget), "Start");
+		gtk_button_set_label(GTK_BUTTON(widget), _("Start"));
 		
-		if(keep_running) {
-		    pid = get_pid_by_name("synergys");
-		    
-		    if(!pid)
-		        pid = get_pid_by_name("synergyc");
-		}
-        
-        kill(pid, SIGTERM);
-        pid = 0;
+        /* kill all synergy processes */
+        system("killall synergys");
+        system("killall synergyc");
+
+        if(!keep_running)
+            wait(&status);
         
         synergy_running = 0;
         
@@ -178,25 +176,35 @@ void start_button_clicked(GtkWidget *widget, gpointer data) {
 }
 
 void close_button_clicked(GtkWidget *widget, gpointer data) {	
-	struct entry_data *entries = (struct entry_data *) data;
+	GtkWidget **entries = (GtkWidget **) data;
+    int status;
 	
     if(synergy_running && !keep_running) {
-        kill(pid, SIGTERM);
+        /* kill all synergy processes */
+        system("killall synergys");
+        system("killall synergyc");
     }
     
-    save_config(entries);
+    save_config(entries[0], entries[1], entries[2], entries[3]);
     
 	gtk_main_quit();
 }
 
 gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
-	struct entry_data *entries = (struct entry_data *) data;
+    GtkWidget **entries = (GtkWidget **) data;
+    int status;
 	
     if(synergy_running && !keep_running) {
-        kill(pid, SIGTERM);
+        if(fork() == 0) {
+            execlp("killall", "killall", "synergys", NULL);
+            execlp("killall", "killall", "synergyc", NULL);
+        }
+        else {
+            wait(&status);
+        }
     }
     
-    save_config(entries);
+    save_config(entries[0], entries[1], entries[2], entries[3]);
     
     return FALSE;
 }
