@@ -1,5 +1,5 @@
 /*  QuickSynergy -- a GUI for synergy
- *  Copyright (C) 2006 César L. B. Silveira, Otávio C. Cordeiro
+ *  Copyright (C) 2006, 2007 Cesar L. B. Silveira, Otavio C. Cordeiro
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,23 +19,25 @@
 #include <sys/types.h>
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include "logo_data.h"
+#include "logo/qslogo.h"
 #include "callbacks.h"
-#include "config.h"
+#include "synergy_config.h"
+#include "screen_entry.h"
 #include "proc.h"
-#include "misc.h"
+#include "config.h"
+#include "intl.h"
 
 GtkWidget *main_window;
 GtkWidget *notebook;
 GtkWidget *hostname_entry;
 GtkWidget *table;
 GtkWidget *vbox0;
+GtkWidget *entries[4];
 int synergy_running = 0;
 int keep_running;
-pid_t pid = 0;
 
 int main(int argc, char **argv) {
-	struct entry_data server_entries;
+    GtkWidget *above_entry, *below_entry, *left_entry, *right_entry;
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *page_label;
@@ -46,7 +48,15 @@ int main(int argc, char **argv) {
 	GtkWidget *check_button;
 	GtkWidget *image;
 	GtkWidget *label;
-	
+    pid_t pid = 0;
+
+#ifdef ENABLE_NLS
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+#endif
+
 	/* initialize GTK */
 	gtk_init(&argc, &argv);
 	
@@ -60,7 +70,7 @@ int main(int argc, char **argv) {
 	
 	/* main window events */
 	g_signal_connect(G_OBJECT(main_window), "delete_event",
-		G_CALLBACK(delete_event), (gpointer) &server_entries);
+		G_CALLBACK(delete_event), (gpointer) entries);
 	g_signal_connect(G_OBJECT(main_window), "destroy",
 		G_CALLBACK(gtk_main_quit), NULL);
 	
@@ -76,61 +86,27 @@ int main(int argc, char **argv) {
 	gtk_container_set_border_width(GTK_CONTAINER(table), 5);
 	
 	/* text entries for server configuration */
-	server_entries.above_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(server_entries.above_entry), "Above");
-	gtk_entry_set_alignment(GTK_ENTRY(server_entries.above_entry), 0.5);
-	gtk_entry_set_width_chars(
-            GTK_ENTRY(server_entries.above_entry), 10);
-	g_signal_connect(
-            G_OBJECT(server_entries.above_entry), "focus-in-event", 
-            G_CALLBACK(entry_focus_in_event), (gpointer) "Above");
-	g_signal_connect(
-            G_OBJECT(server_entries.above_entry), "focus-out-event",
-            G_CALLBACK(entry_focus_out_event), (gpointer) "Above");
-    
-    /* attach entry to table */
-	gtk_table_attach_defaults(GTK_TABLE(table), 
-            server_entries.above_entry, 1, 2, 0, 1);
+	above_entry = screen_entry_new(_("Above"));
+	below_entry = screen_entry_new(_("Below"));
+	left_entry = screen_entry_new(_("Left"));
+	right_entry = screen_entry_new(_("Right"));
+
+    /* attach entries to table */
+	gtk_table_attach_defaults(GTK_TABLE(table), above_entry, 1, 2, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(table), below_entry, 1, 2, 2, 3);
+	gtk_table_attach_defaults(GTK_TABLE(table), left_entry, 0, 1, 1, 2);			
+	gtk_table_attach_defaults(GTK_TABLE(table), right_entry, 2, 3, 1, 2);
 	
-	server_entries.below_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(server_entries.below_entry), "Below");
-	gtk_entry_set_alignment(GTK_ENTRY(server_entries.below_entry), 0.5);
-	gtk_entry_set_width_chars(GTK_ENTRY(server_entries.below_entry), 10);
-	g_signal_connect(G_OBJECT(server_entries.below_entry), "focus-in-event",
-		G_CALLBACK(entry_focus_in_event), (gpointer) "Below");
-	g_signal_connect(G_OBJECT(server_entries.below_entry), "focus-out-event",
-		G_CALLBACK(entry_focus_out_event), (gpointer) "Below");
-		
-    /* attach entry to table */
-	gtk_table_attach_defaults(GTK_TABLE(table), server_entries.below_entry, 1, 2, 2, 3);
-	
-	server_entries.left_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(server_entries.left_entry), "Left");
-	gtk_entry_set_alignment(GTK_ENTRY(server_entries.left_entry), 0.5);
-	gtk_entry_set_width_chars(GTK_ENTRY(server_entries.left_entry), 10);
-	g_signal_connect(G_OBJECT(server_entries.left_entry), "focus-in-event",
-		G_CALLBACK(entry_focus_in_event), (gpointer) "Left");
-	g_signal_connect(G_OBJECT(server_entries.left_entry), "focus-out-event",
-		G_CALLBACK(entry_focus_out_event), (gpointer) "Left");
-		
-    /* attach entry to table */
-	gtk_table_attach_defaults(GTK_TABLE(table), server_entries.left_entry, 0, 1, 1, 2);	
-	
-	server_entries.right_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(server_entries.right_entry), "Right");
-	gtk_entry_set_alignment(GTK_ENTRY(server_entries.right_entry), 0.5);
-	gtk_entry_set_width_chars(GTK_ENTRY(server_entries.right_entry), 10);
-	g_signal_connect(G_OBJECT(server_entries.right_entry), "focus-in-event",
-		G_CALLBACK(entry_focus_in_event), (gpointer) "Right");
-	g_signal_connect(G_OBJECT(server_entries.right_entry), "focus-out-event",
-		G_CALLBACK(entry_focus_out_event), (gpointer) "Right");
-		
-    /* attach entry to table */
-	gtk_table_attach_defaults(GTK_TABLE(table), server_entries.right_entry, 2, 3, 1, 2);
+	entries[0] = above_entry;
+	entries[1] = below_entry;
+	entries[2] = left_entry;
+	entries[3] = right_entry;			
 	
 	/* image to be displayed in the center of the main window */
+	//image = gtk_image_new_from_pixbuf(
+	//	gdk_pixbuf_new_from_xpm_data((const char **) logo_data));
 	image = gtk_image_new_from_pixbuf(
-		gdk_pixbuf_new_from_xpm_data((const char **) logo_data));
+		gdk_pixbuf_new_from_inline(-1, qslogo, FALSE, NULL));
 	gtk_table_attach_defaults(GTK_TABLE(table), image, 1, 2, 1, 2);
 	
 	/*
@@ -141,14 +117,14 @@ int main(int argc, char **argv) {
 	*/
 	
 	/* add server page to the notebook */
-	page_label = gtk_label_new("Server");
+	page_label = gtk_label_new(_("Share"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, page_label);
 	
 	/* client's vbox */
 	vbox0 = gtk_vbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox0), 5);
 	
-	label = gtk_label_new("Server hostname/IP address:");
+	label = gtk_label_new(_("Server hostname/IP address:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
 	gtk_box_pack_start(GTK_BOX(vbox0), label, FALSE, FALSE, 0);
 	
@@ -157,7 +133,7 @@ int main(int argc, char **argv) {
 	gtk_box_pack_start(GTK_BOX(vbox0), hostname_entry, FALSE, FALSE, 0);	
 	
 	/* add client page to notebook */
-	page_label = gtk_label_new("Client");
+	page_label = gtk_label_new(_("Use"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox0, page_label);
 	
 	/* settings page */
@@ -166,13 +142,13 @@ int main(int argc, char **argv) {
 	
 	/* check button for setting the KeepRunning option */
 	check_button = gtk_check_button_new_with_label(
-	    "Keep synergy running after QuickSynergy is closed");
+	    _("Keep synergy running after QuickSynergy is closed"));
 	g_signal_connect(G_OBJECT(check_button), "toggled",
 	    G_CALLBACK(keep_running_toggled), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox0), check_button, FALSE, FALSE, 0);
 	
 	/* add settings page to notebook */
-	page_label = gtk_label_new("Settings");
+	page_label = gtk_label_new(_("Settings"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox0, page_label);
 	
 	/* pack the notebook into the main vbox */
@@ -186,28 +162,28 @@ int main(int argc, char **argv) {
 	hbox =  gtk_hbox_new(TRUE, 22);
 	
 	/* about button */
-	about_button = gtk_button_new_with_label("About");
+	about_button = gtk_button_new_with_label(_("About"));
 	g_signal_connect(G_OBJECT(about_button), "clicked",
 		G_CALLBACK(about_button_clicked), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox), about_button, TRUE, TRUE, 0);
 	
 	/* start/stop button */
-	start_button = gtk_button_new_with_label("Start");
+	start_button = gtk_button_new_with_label(_("Start"));
 	g_signal_connect(G_OBJECT(start_button), "clicked",
-		G_CALLBACK(start_button_clicked), (gpointer) &server_entries);
+		G_CALLBACK(start_button_clicked), (gpointer) entries);
 	gtk_box_pack_start(GTK_BOX(hbox), start_button, TRUE, TRUE, 0);	
 	
 	/* close button */
-  	close_button = gtk_button_new_with_label("Close");
+  	close_button = gtk_button_new_with_label(_("Close"));
 	g_signal_connect(G_OBJECT(close_button), "clicked",
-		G_CALLBACK(close_button_clicked), (gpointer) &server_entries);
+		G_CALLBACK(close_button_clicked), (gpointer) entries);
     gtk_box_pack_start(GTK_BOX(hbox), close_button, TRUE, TRUE, 0);
 	
 	/* pack the hbox into the main vbox */
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
 	
 	/* load previous configuration */
-	load_config(&server_entries);
+	load_config(above_entry, below_entry, left_entry, right_entry);
 	
 	/* if the KeepRunning configuration option is 1, set the
 	 * settings check button to an active state */
@@ -217,12 +193,12 @@ int main(int argc, char **argv) {
 	
 	/* check if synergy is already running */
 	if((pid = get_pid_by_name("synergys"))) {
-		gtk_button_set_label(GTK_BUTTON(start_button), "Stop");
+		gtk_button_set_label(GTK_BUTTON(start_button), _("Stop"));
 		gtk_widget_set_sensitive(notebook, FALSE);
 		synergy_running = 1;
 	}
 	else if((pid = get_pid_by_name("synergyc"))) {
-		gtk_button_set_label(GTK_BUTTON(start_button), "Stop");
+		gtk_button_set_label(GTK_BUTTON(start_button), _("Stop"));
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
 		gtk_widget_set_sensitive(notebook, FALSE);
 		synergy_running = 1;
